slepc-3.18.0 2022-10-01
Report Typos and Errors

# NEPSLPGetKSP

Retrieve the linear solver object (KSP) associated with the nonlinear eigenvalue solver.

### Synopsis

    #include "slepcnep.h"
    PetscErrorCode NEPSLPGetKSP(NEP nep,KSP *ksp)

Not Collective

### Input Parameter

| nep | - nonlinear eigenvalue solver

### Output Parameter

| ksp | - the linear solver object

### See Also

NEPSLPSetKSP()

### Level

advanced

### Location

src/nep/impls/slp/slp.c
Index of all NEP routines
Table of Contents for all manual pages
Index of all manual pages